@@ -7,7 +7,7 @@ class ESP300:
     def __init__(self, port):
         self.rm = pyvisa.ResourceManager()
         current_port = port.name
-        self.esp = self.rm.open_resource(f'ASRL/{current_port}::INSTR')
+        self.esp = self.rm.open_resource(f'ASRL/dev/{current_port}::INSTR')
         self.esp.baud_rate = 19200
 
     def moveAbs(self,axis, position):
